--    FILE: MapMod.lua
--    DATE: 17-10-10
--  AUTHOR: Vitruviusxv
-- PURPOSE: Makes the (default) minimap customizable

--[[ NOTES: VERSION - 1.0.0

            - Alpha version, proof of concept (to myself)

            VERSION - 1.0.1

            - Changed GUI frame strata so it's not underneath my player frames
            - Fixed Slider Values, so default-sized map can't be moved off screen
            - Fixed TIME icon, so it's removed when Blizzard_TimeManager loads, otherwise it's shown regardless
            - Fixed sliders so they show the CURRENT values when GUI is opened
            - Fixed the text BENEATH each end of the sliders to represent what the slider value changes
            - Registered event UPDATE_PENDING_MAIL to hide icon when new mail is received

]]

--__________________________________________________
-- VARIABLES

local prefix = "\124cFF00FF00<MinimapMod>\124cFFFFFFFF"

local MapModFrame = CreateFrame("Frame",nil,UIParent)

--__________________________________________________

local ShowHelp = function()

   print(prefix.." /mm or /mapmod to configure")

end -- FUNCTION(ShowHelp)

--__________________________________________________

local CreateConfigBox = function()

-- CREATING CONFIG FRAME

MapModFrame:ClearAllPoints()
MapModFrame:SetBackdrop(StaticPopup1:GetBackdrop())
MapModFrame:SetHeight(460)
MapModFrame:SetWidth(300)
MapModFrame:SetPoint("CENTER")
MapModFrame:SetFrameStrata("HIGH")
 
MapModFrame.Title = MapModFrame:CreateFontString(nil, "BACKGROUND", "GameFontNormal")
MapModFrame.Title:SetPoint("TOP",MapModFrame,"TOP",0,-20)
MapModFrame.Title:SetText("MinimapMod 1.3")

-- Movable

MapModFrame:SetMovable(true)
MapModFrame:EnableMouse(true)
MapModFrame:RegisterForDrag("LeftButton")
MapModFrame:SetScript("OnDragStart",MapModFrame.StartMoving)
MapModFrame:SetScript("OnDragStop",MapModFrame.StopMovingOrSizing)

-- CLOSE BUTTON

MapModFrame.Close = CreateFrame("Button",nil,MapModFrame,"UIPanelCloseButton")
MapModFrame.Close:SetWidth(25)
MapModFrame.Close:SetHeight(25)
MapModFrame.Close:SetPoint("TOPRIGHT",MapModFrame,"TOPRIGHT",-10,-10)


-- MAP CHECKBOX

MapModFrame.MapButton = CreateFrame("CheckButton","MapButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.MapButton:SetPoint("TOPLEFT",MapModFrame,"TOPLEFT",20,-50)
if MapModSettings.ShowMap then
   MapModFrame.MapButton:SetChecked(1)
end
MapModFrame.MapButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      MinimapCluster:Show()
      MapModSettings.ShowMap = true

      -- ENABLE ALL THE OTHER CHECKBOXES
      MapModFrame.TimeButton:Enable()
      MapModFrame.ZoneButton:Enable()
      MapModFrame.CalendarButton:Enable()
      MapModFrame.ZoomButton:Enable()
      MapModFrame.TrackButton:Enable()
      MapModFrame.MailButton:Enable()
      MapModFrame.LFGButton:Enable()
      MapModFrame.DifficultyButton:Enable()
   
      MapModFrame.ScaleSlider:Enable()
      MapModFrame.XoffSlider:Enable()
      MapModFrame.YoffSlider:Enable()
     

   else

      MinimapCluster:Hide()
      MapModSettings.ShowMap = false

      -- DISABLE ALL THE OTHER CHECKBOXES
      MapModFrame.TimeButton:Disable()
      MapModFrame.ZoneButton:Disable()
      MapModFrame.CalendarButton:Disable()
      MapModFrame.ZoomButton:Disable()
      MapModFrame.TrackButton:Disable()
      MapModFrame.MailButton:Disable()
      MapModFrame.LFGButton:Disable()
      MapModFrame.DifficultyButton:Disable()

      MapModFrame.ScaleSlider:Disable()
      MapModFrame.XoffSlider:Disable()
      MapModFrame.YoffSlider:Disable()

   end -- IF/ELSE

end)
MapModFrame.MapText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.MapText:SetPoint("LEFT",MapModFrame.MapButton,"RIGHT",0,0)
MapModFrame.MapText:SetText("show minimap")


-- TIME CHECKBOX

MapModFrame.TimeButton = CreateFrame("CheckButton","TimeButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.TimeButton:SetPoint("TOPLEFT",MapModFrame.MapButton,"BOTTOMLEFT")
if MapModSettings.ShowTime then
   MapModFrame.TimeButton:SetChecked(1)
end
MapModFrame.TimeButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      TimeManagerClockButton:Show()
      MapModSettings.ShowTime = true

   else

      TimeManagerClockButton:Hide()
      MapModSettings.ShowTime = false

   end -- IF/ELSE

end)
MapModFrame.TimeText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.TimeText:SetPoint("LEFT",MapModFrame.TimeButton,"RIGHT",0,3)
MapModFrame.TimeText:SetText("show map time")


-- ZONE CHECKBOX

MapModFrame.ZoneButton = CreateFrame("CheckButton","ZoneButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.ZoneButton:SetPoint("TOPLEFT",MapModFrame.TimeButton,"BOTTOMLEFT")
if MapModSettings.ShowZone then
   MapModFrame.ZoneButton:SetChecked(1)
end
MapModFrame.ZoneButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      MinimapBorderTop:Show()
      MinimapZoneTextButton:Show()
      MiniMapWorldMapButton:Show()
      MapModSettings.ShowZone = true

   else

      MinimapBorderTop:Hide()
      MinimapZoneTextButton:Hide()
      MiniMapWorldMapButton:Hide()
      MapModSettings.ShowZone = false

   end -- IF/ELSE

end)
MapModFrame.ZoneText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.ZoneText:SetPoint("LEFT",MapModFrame.ZoneButton,"RIGHT",0,0)
MapModFrame.ZoneText:SetText("show zone")


-- CALENDAR CHECKBOX

MapModFrame.CalendarButton = CreateFrame("CheckButton","ZoneButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.CalendarButton:SetPoint("TOPLEFT",MapModFrame.ZoneButton,"BOTTOMLEFT")
if MapModSettings.ShowCalendar then
   MapModFrame.CalendarButton:SetChecked(1)
end
MapModFrame.CalendarButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      GameTimeFrame:Show()
      MapModSettings.ShowCalendar = true

   else

      GameTimeFrame:Hide()
      MapModSettings.ShowCalendar = false

   end -- IF/ELSE

end)
MapModFrame.CalendarText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.CalendarText:SetPoint("LEFT",MapModFrame.CalendarButton,"RIGHT",0,0)
MapModFrame.CalendarText:SetText("show calendar")


-- ZOOM CHECKBOX

MapModFrame.ZoomButton = CreateFrame("CheckButton","ZoomButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.ZoomButton:SetPoint("TOPLEFT",MapModFrame.CalendarButton,"BOTTOMLEFT")
if MapModSettings.ShowZoom then
   MapModFrame.ZoomButton:SetChecked(1)
end
MapModFrame.ZoomButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      MinimapZoomIn:Show()
      MinimapZoomOut:Show()
      MapModSettings.ShowZoom = true

   else

      MinimapZoomIn:Hide()
      MinimapZoomOut:Hide()
      MapModSettings.ShowZoom = false

   end -- IF/ELSE

end)
MapModFrame.ZoomText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.ZoomText:SetPoint("LEFT",MapModFrame.ZoomButton,"RIGHT",0,0)
MapModFrame.ZoomText:SetText("show zoom buttons")


-- TRACKING CHECKBOX

MapModFrame.TrackButton = CreateFrame("CheckButton","TrackButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.TrackButton:SetPoint("TOPLEFT",MapModFrame.ZoomButton,"BOTTOMLEFT")
if MapModSettings.ShowTracking then
   MapModFrame.TrackButton:SetChecked(1)
end
MapModFrame.TrackButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      MiniMapTracking:Show()
      MapModSettings.Tracking = true

   else

      MiniMapTracking:Hide()
      MapModSettings.ShowTracking = false

   end -- IF/ELSE

end)
MapModFrame.TrackText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.TrackText:SetPoint("LEFT",MapModFrame.TrackButton,"RIGHT",0,0)
MapModFrame.TrackText:SetText("show tracking button")


-- MAIL CHECKBOX

MapModFrame.MailButton = CreateFrame("CheckButton","MailButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.MailButton:SetPoint("TOPLEFT",MapModFrame.TrackButton,"BOTTOMLEFT")
if MapModSettings.ShowMail then
   MapModFrame.MailButton:SetChecked(1)
end
MapModFrame.MailButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      MiniMapMailFrame:Show()
      MapModSettings.ShowMail = true

   else

      MiniMapMailFrame:Hide()
      MapModSettings.ShowMail = false

   end -- IF/ELSE

end)
MapModFrame.MailText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.MailText:SetPoint("LEFT",MapModFrame.MailButton,"RIGHT",0,0)
MapModFrame.MailText:SetText("show mail icon")


-- LFG CHECKBOX

MapModFrame.LFGButton = CreateFrame("CheckButton","LFGButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.LFGButton:SetPoint("TOPLEFT",MapModFrame.MailButton,"BOTTOMLEFT")
if MapModSettings.ShowLFG then
   MapModFrame.LFGButton:SetChecked(1)
end
MapModFrame.LFGButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      local isLooking = GetLFGQueueStats()

      if (isLooking) then

         MiniMapLFGFrame:Show()

      end --IFlooking

      MapModSettings.ShowLFG = true

   else

      MiniMapLFGFrame:Hide()
      MapModSettings.ShowLFG = false

   end -- IF/ELSE

end)
MapModFrame.LFGText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.LFGText:SetPoint("LEFT",MapModFrame.LFGButton,"RIGHT",0,0)
MapModFrame.LFGText:SetText("show LFG dungeon icon")


-- DIFFICULTY CHECKBOX

MapModFrame.DifficultyButton = CreateFrame("CheckButton","DifficultyButton",MapModFrame,"ChatConfigCheckButtonTemplate")
MapModFrame.DifficultyButton:SetPoint("TOPLEFT",MapModFrame.LFGButton,"BOTTOMLEFT")
if MapModSettings.ShowDifficulty then
   MapModFrame.DifficultyButton:SetChecked(1)
end
MapModFrame.DifficultyButton:SetScript("OnClick",function(self)

   if (self:GetChecked()) then

      local check,which = IsInInstance()

      if (check) and (which == "party" or "raid") then

         MiniMapInstanceDifficulty:Show()

      end -- IFinstance

      MapModSettings.ShowDifficulty = true

   else

      MiniMapInstanceDifficulty:Hide()
      MapModSettings.ShowDifficulty = false

   end -- IF/ELSE

end)
MapModFrame.DifficultyText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.DifficultyText:SetPoint("LEFT",MapModFrame.DifficultyButton,"RIGHT",0,0)
MapModFrame.DifficultyText:SetText("show dungeon difficulty flag")


-- SCALE SLIDER

MapModFrame.ScaleSlider = CreateFrame("Slider","ScaleSlider",MapModFrame,"OptionsSliderTemplate")
MapModFrame.ScaleSlider:SetPoint("TOPLEFT",MapModFrame.DifficultyButton,"BOTTOMLEFT",50,-40)
MapModFrame.ScaleSlider:SetMinMaxValues(0.5,3)
MapModFrame.ScaleSlider:SetValueStep(0.1)

-- FOR LATER -- local _,_,_,x,y = MinimapCluster:GetPoint(1) -- returns the x,y value
local scale = MinimapCluster:GetScale()

MapModFrame.ScaleSlider:SetValue(scale)
MapModFrame.ScaleSlider:SetScript("OnLoad",function(self)

   getglobal(self:GetName().."Low"):SetText("Left")
   getglobal(self:GetName().."High"):SetText("Right")

end)

MapModFrame.ScaleSlider:SetScript("OnValueChanged",function(self,value)

   MinimapCluster:SetScale(value)
   MapModSettings.Scale = value

end) -- VALUECHANGED

MapModFrame.ScaleText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.ScaleText:SetPoint("BOTTOM",MapModFrame.ScaleSlider,"TOP",0,5)
MapModFrame.ScaleText:SetText("map scale")


-- X OFFSET SLIDER

MapModFrame.XoffSlider = CreateFrame("Slider","XoffSlider",MapModFrame,"OptionsSliderTemplate")
MapModFrame.XoffSlider:SetPoint("TOP",MapModFrame.ScaleSlider,"BOTTOM",0,-30)
local MaxWidth = GetScreenWidth() * 2 -- MinimapCluster:GetWidth()
MapModFrame.XoffSlider:SetMinMaxValues(-MaxWidth,0)
MapModFrame.XoffSlider:SetValueStep(1)

local _,_,_,x,y = MinimapCluster:GetPoint(1) -- returns the x,y value

MapModFrame.XoffSlider:SetValue(x)
MapModFrame.XoffSlider:SetScript("OnLoad",function(self)

   --(MapModXoffSlider:GetName()).."Low":SetText("left")
   --getglobal(self:GetName().."High"):SetText("Right")

end)

MapModFrame.XoffSlider:SetScript("OnValueChanged",function(self,value)

   MinimapCluster:ClearAllPoints()
   MinimapCluster:SetPoint("TOPRIGHT",UIParent,"TOPRIGHT",value,MapModSettings.AnchorOffy)
   MapModSettings.AnchorOffx = value

end) -- VALUECHANGED

MapModFrame.XoffText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.XoffText:SetPoint("BOTTOM",MapModFrame.XoffSlider,"TOP",0,5)
MapModFrame.XoffText:SetText("x offset")



-- Y OFFSET SLIDER

MapModFrame.YoffSlider = CreateFrame("Slider","YoffSlider",MapModFrame,"OptionsSliderTemplate")
MapModFrame.YoffSlider:SetPoint("TOP",MapModFrame.XoffSlider,"BOTTOM",0,-30)
local MaxHeight = GetScreenHeight() * 2 -- MinimapCluster:GetHeight()
MapModFrame.YoffSlider:SetMinMaxValues(-MaxHeight,0)
MapModFrame.YoffSlider:SetValueStep(1)

local _,_,_,x,y = MinimapCluster:GetPoint(1) -- returns the x,y value

MapModFrame.YoffSlider:SetValue(y)
MapModFrame.YoffSlider:SetScript("OnLoad",function(self)

   getglobal(self:GetName().."Low"):SetText("Left")
   getglobal(self:GetName().."High"):SetText("Right")

end)

MapModFrame.YoffSlider:SetScript("OnValueChanged",function(self,value)

   MinimapCluster:ClearAllPoints()
   MinimapCluster:SetPoint("TOPRIGHT",UIParent,"TOPRIGHT",MapModSettings.AnchorOffx,value)
   MapModSettings.AnchorOffy = value

end) -- VALUECHANGED

MapModFrame.YoffText = MapModFrame:CreateFontString(nil,nil,"GameFontNormal")
MapModFrame.YoffText:SetPoint("BOTTOM",MapModFrame.YoffSlider,"TOP",0,5)
MapModFrame.YoffText:SetText("y offset")

MapModFrame:Hide()

end -- FUNCTION(CreateConfigBox)

--__________________________________________________

Variables_Handler = function()

   if not MapModSettings then

      MapModSettings = {}

         MapModSettings.Version = 1.3
         MapModSettings.ShowMap = true
         MapModSettings.ShowZone = true
         MapModSettings.ShowTime = true
         MapModSettings.ShowMail = true
         MapModSettings.ShowCalendar = true
         MapModSettings.ShowTracking = true
         MapModSettings.ShowDifficulty = true
         MapModSettings.ShowPVP = true
         MapModSettings.ShowLFG = true
         MapModSettings.ShowZoom = true
         MapModSettings.AnchorOffx = 0
         MapModSettings.AnchorOffy = 0
         MapModSettings.Scale = 1

   end -- IF(MapModSettings)

   if (MapModSettings.Version < 1.3) then

      -- UPDATE THE SETTINGS

         MapModSettings.Version = 1.3
         MapModSettings.ShowMap = MapModSettings.ShowMap or true
         MapModSettings.ShowZone = MapModSettings.ShowZone or true
         MapModSettings.ShowTime = MapModSettings.ShowTime or true
         MapModSettings.ShowMail = MapModSettings.ShowMail or true
         MapModSettings.ShowCalendar = MapModSettings.ShowCalendar or true
         MapModSettings.ShowTracking = MapModSettings.ShowTracking or true
         MapModSettings.ShowDifficulty = MapModSettings.ShowDifficulty or true
         MapModSettings.ShowLFG = MapModSettings.ShowLFG or true
         MapModSettings.ShowPVP = MapModSettings.ShowPVP or true
         MapModSettings.ShowZoom = MapModSettings.ShowZoom or true
         MapModSettings.AnchorOffx = MapModSettings.AnchorOffx or 0
         MapModSettings.AnchorOffy = MapModSettings.AnchorOffy or 0
         MapModSettings.Scale = MapModSettings.Scale or 1

      print(prefix.." Settings updated for version "..MapModSettings.Version)

   end -- VERSION

   CreateConfigBox()

   -- SET MAP UP

   -- ** map position & scale

   MinimapCluster:ClearAllPoints()
   MinimapCluster:SetPoint("TOPRIGHT",UIParent,"TOPRIGHT",MapModSettings.AnchorOffx,MapModSettings.AnchorOffy)
   MinimapCluster:SetScale(MapModSettings.Scale)

   if not (MapModSettings.ShowMap) then

      MinimapCluster:Hide()

   end -- MAP

   -- ** hide/show buttons n stuff

   if not (MapModSettings.ShowZone) then

      MinimapBorderTop:Hide()
      MiniMapWorldMapButton:Hide()
      MinimapZoneTextButton:Hide()

   end -- ZONE

   if not (MapModSettings.ShowZoom) then

      MinimapZoomIn:Hide()
      MinimapZoomOut:Hide()

   end -- ZOOM



   if not (MapModSettings.ShowTracking) then

      MiniMapTracking:Hide()
 
   end -- TRACKING

   if not (MapModSettings.ShowCalendar) then

      GameTimeFrame:Hide()

   end -- CALENDAR

   -- SET SLIDER POSITIONS & change text

   MapModFrame.ScaleSlider:SetValue(MinimapCluster:GetScale())
   getglobal(MapModFrame.ScaleSlider:GetName() .. 'Low'):SetText('small')
   getglobal(MapModFrame.ScaleSlider:GetName() .. 'High'):SetText('large')

   local _,_,_,x,y = MinimapCluster:GetPoint(1)
   MapModFrame.XoffSlider:SetValue(x)
   getglobal(MapModFrame.XoffSlider:GetName() .. 'Low'):SetText('left')
   getglobal(MapModFrame.XoffSlider:GetName() .. 'High'):SetText('right')

   MapModFrame.YoffSlider:SetValue(y)
   getglobal(MapModFrame.YoffSlider:GetName() .. 'Low'):SetText('down')
   getglobal(MapModFrame.YoffSlider:GetName() .. 'High'):SetText('up')

   MapTimerFrame = CreateFrame("Frame")
   MapTimerFrame:RegisterEvent("ADDON_LOADED")
   MapTimerFrame:RegisterEvent("UPDATE_PENDING_MAIL")
   MapTimerFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
   MapTimerFrame:RegisterEvent("LFG_UPDATE")
   MapTimerFrame:RegisterEvent("LFG_QUEUE_STATUS_UPDATE")
   MapTimerFrame:RegisterEvent("UPDATE_INSTANCE_INFO")
   MapTimerFrame:SetScript("OnEvent",MapTimer)

   -- CLAMP MINIMAP TO SCREEN!
   MinimapCluster:SetClampedToScreen(true)

   ShowHelp()

end -- FUNCTION(Variables_Handler)

--__________________________________________________

function MapTimer(self,event,addon)

   if (event == "LFG_UPDATE") then

      if not (MapModSettings.ShowLFG) then

         MiniMapLFGFrame:Hide()
         return

      else

         return

      end -- IFnot

      if not (MapModSettings.ShowDifficulty) then

         MiniMapInstanceDifficulty:Hide()

      end --IFnot

   print("event")

   end -- LFG

   if (event == "UPDATE_INSTANCE_INFO") then

      if not (MapModSettings.ShowDifficulty) then

         MiniMapInstanceDifficulty:Hide()
         return

      end --IFnot

   end -- IFevent

   if (event == "LFG_QUEUE_STATUS_UPDATE") then

      if not (MiniMapLFGFrame:IsShown()) and (MapModSettings.ShowLFG) then

         MiniMapLFGFrame:Show()
         return

      else

         return

      end

   end -- IFlfg

   if (addon == "Blizzard_TimeManager") then

      if not (MapModSettings.ShowTime) then

         TimeManagerClockButton:Hide()
         return

      else

         return

      end -- Ifnot

   end -- IFaddon

   if (event == "UPDATE_PENDING_MAIL") then

      if not (MapModSettings.ShowMail) then

         MiniMapMailFrame:Hide()
         return

      else

         return

      end -- IFnot

   end -- MAIL

   if (event == "PLAYER_ENTERING_WORLD") then

      if not (MapModSettings.ShowLFG) then

         MiniMapInstanceDifficulty:Hide()

      end -- IFnot

   end -- IfenteringWorld

end -- FUNCTION(MountTimer)

--__________________________________________________
-- SLASH HANDLERS

SLASH_MAPMOD1,SLASH_MAPMOD2 = "/mm","/mapmod"

SlashCmdList["MAPMOD"] = function()

   -- CHANGE THE SLIDER INITIAL VALUES


   MapModFrame:Show()

end -- FUNCTION(slash_handler)

--__________________________________________________

MapModFrame:RegisterEvent("VARIABLES_LOADED")
MapModFrame:SetScript("OnEvent",Variables_Handler)
